otter package
=============

Submodules
----------

otter.bootstrap module
----------------------

.. automodule:: otter.bootstrap
    :members:
    :undoc-members:
    :show-inheritance:

otter.html module
-----------------

.. automodule:: otter.html
    :members:
    :undoc-members:
    :show-inheritance:

otter.otter module
------------------

.. automodule:: otter.otter
    :members:
    :undoc-members:
    :show-inheritance:

otter.plot module
-----------------

.. automodule:: otter.plot
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: otter
    :members:
    :undoc-members:
    :show-inheritance:
